@@ -391,9 +391,9 @@ def list_make():
     
     lmax = len(max(vals , key = lambda x : len(x[0]) )[0]) % os.get_terminal_size().columns 
     
-    termcolor.cprint('Name' , end = '' , color = 'yellow')
+    termcolor.cprint('Name'.jlust(lmax) , end = '' , color = 'cyan')
     print(' : ' , end = '' )
-    termcolor.cprint('Description' , color = 'green')
+    termcolor.cprint('Description' , color = 'yellow')
     
     for name , description in vals:
         termcolor.cprint(name.ljust(lmax) , end = '' , color = 'yellow')
